@@ -69,14 +69,16 @@ class Wsdl(WsdlBase):
                                     'cl_update_other_set',
                                     'cl_update_pretend_set',
                                     'cl_update_sync_rep',
-                                    'cl_update_cleanpkg_set',
                                     'cl_update_emergelist_set',
                                     'cl_update_world',
                                     'cl_update_egencache_force',
                                     'cl_update_eixupdate_force',
+                                    'cl_update_skip_rb_set',
                                     'cl_update_wait_another_set',
-                                    'cl_update_branch',
                                     'cl_update_autocheck_schedule_set',
+                                    'cl_update_binhost_recheck_set',
+                                    'cl_update_cleanpkg_set',
+                                    'cl_update_branch_data',
                                     'cl_templates_locate',
                                     'cl_verbose_set', 'cl_dispatch_conf'),
                                     next_label=_("Perform"))]},
@@ -91,7 +93,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Change the Profile"),
             # иконка для графической консоли
-            'image': 'extension',
+            'image': 'notification-display-brightness-full,gtk-dialog-info,'
+                     'help-hint',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -112,11 +115,10 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(_("Repository"),
                                     brief=('cl_update_profile_repo_name',),
-                                    hide=('cl_update_profile_rep',
+                                    hide=('cl_update_profile_url',
                                           'cl_update_profile_sync_set'),
-                                    normal=('cl_update_profile_rep',),
-                                    expert=('cl_update_profile_sync_set',
-                                            'cl_update_profile_branch')),
+                                    normal=('cl_update_profile_url',),
+                                    expert=('cl_update_profile_sync_set',)),
                 lambda group: group(_("Profile"),
                                     normal=('cl_update_profile_system',
                                             'cl_update_world'),
